@@ -10,8 +10,8 @@ from typing import Dict, Any
 _tables: Dict[str, Any] = {}
 _streams: Dict[str, Any] = {}
 _ingest_apis: Dict[str, Any] = {}
-_egress_apis: Dict[str, Any] = {}
+_apis: Dict[str, Any] = {}
 # Alias map for O(1) fallback of sole versioned APIs: base name -> handler
-_egress_api_name_aliases: Dict[str, Any] = {}
+_api_name_aliases: Dict[str, Any] = {}
 _sql_resources: Dict[str, Any] = {}
 _workflows: Dict[str, Any] = {} 
\ No newline at end of file
