@@ -7,10 +7,11 @@ to convert the user-defined resources (from `dmv2.py`) into a serializable
 JSON format expected by the Moose infrastructure management system.
 """
 from importlib import import_module
-from typing import Literal, Optional, List, Any
+from typing import Literal, Optional, List, Any, Dict, Union, TYPE_CHECKING
 from pydantic import BaseModel, ConfigDict, AliasGenerator, Field
 import json
 from .data_models import Column, _to_columns
+from .blocks import EngineConfig, ClickHouseEngines
 from moose_lib.dmv2 import (
     get_tables,
     get_streams,
@@ -53,6 +54,48 @@ class Consumer(BaseModel):
     """
     version: Optional[str] = None
 
+class BaseEngineConfigDict(BaseModel):
+    """Base engine configuration for all ClickHouse table engines."""
+    model_config = model_config
+    engine: str
+
+class MergeTreeConfigDict(BaseEngineConfigDict):
+    """Configuration for MergeTree engine."""
+    engine: Literal["MergeTree"] = "MergeTree"
+
+class ReplacingMergeTreeConfigDict(BaseEngineConfigDict):
+    """Configuration for ReplacingMergeTree engine."""
+    engine: Literal["ReplacingMergeTree"] = "ReplacingMergeTree"
+    ver: Optional[str] = None
+    is_deleted: Optional[str] = None
+
+class AggregatingMergeTreeConfigDict(BaseEngineConfigDict):
+    """Configuration for AggregatingMergeTree engine."""
+    engine: Literal["AggregatingMergeTree"] = "AggregatingMergeTree"
+
+class SummingMergeTreeConfigDict(BaseEngineConfigDict):
+    """Configuration for SummingMergeTree engine."""
+    engine: Literal["SummingMergeTree"] = "SummingMergeTree"
+
+class S3QueueConfigDict(BaseEngineConfigDict):
+    """Configuration for S3Queue engine with all specific fields."""
+    engine: Literal["S3Queue"] = "S3Queue"
+    s3_path: str
+    format: str
+    aws_access_key_id: Optional[str] = None
+    aws_secret_access_key: Optional[str] = None
+    compression: Optional[str] = None
+    headers: Optional[Dict[str, str]] = None
+
+# Discriminated union of all engine configurations
+EngineConfigDict = Union[
+    MergeTreeConfigDict,
+    ReplacingMergeTreeConfigDict,
+    AggregatingMergeTreeConfigDict,
+    SummingMergeTreeConfigDict,
+    S3QueueConfigDict
+]
+
 class TableConfig(BaseModel):
     """Internal representation of an OLAP table configuration for serialization.
 
@@ -60,20 +103,22 @@ class TableConfig(BaseModel):
         name: Name of the table.
         columns: List of columns with their types and attributes.
         order_by: List of columns used for the ORDER BY clause.
-        engine: The name of the ClickHouse engine used.
+        engine_config: Engine configuration with type-safe, engine-specific parameters.
         version: Optional version string of the table configuration.
         metadata: Optional metadata for the table.
         life_cycle: Lifecycle management setting for the table.
+        table_settings: Optional table-level settings that can be modified with ALTER TABLE MODIFY SETTING.
     """
     model_config = model_config
 
     name: str
     columns: List[Column]
     order_by: List[str]
-    engine: Optional[str]
+    engine_config: Optional[EngineConfigDict] = Field(None, discriminator='engine')
     version: Optional[str] = None
     metadata: Optional[dict] = None
     life_cycle: Optional[str] = None
+    table_settings: Optional[Dict[str, str]] = None
 
 class TopicConfig(BaseModel):
     """Internal representation of a stream/topic configuration for serialization.
@@ -249,6 +294,89 @@ def _map_sql_resource_ref(r: Any) -> InfrastructureSignatureJson:
         raise TypeError(f"Object {r} lacks a 'kind' attribute for dependency mapping.")
 
 
+def _convert_engine_to_config_dict(engine: Union[ClickHouseEngines, EngineConfig], table: OlapTable) -> EngineConfigDict:
+    """Convert engine enum or EngineConfig instance to new engine config format.
+    
+    Args:
+        engine: Either a ClickHouseEngines enum value or an EngineConfig instance
+        table: The OlapTable instance with configuration
+        
+    Returns:
+        EngineConfigDict with engine-specific configuration
+    """
+    from moose_lib import ClickHouseEngines
+    from moose_lib.blocks import (
+        EngineConfig, S3QueueEngine, MergeTreeEngine, 
+        ReplacingMergeTreeEngine, AggregatingMergeTreeEngine, 
+        SummingMergeTreeEngine
+    )
+    from moose_lib.commons import Logger
+    
+    # Check if engine is an EngineConfig instance (new API)
+    if isinstance(engine, EngineConfig):
+        if isinstance(engine, S3QueueEngine):
+            return S3QueueConfigDict(
+                s3_path=engine.s3_path,
+                format=engine.format,
+                aws_access_key_id=engine.aws_access_key_id,
+                aws_secret_access_key=engine.aws_secret_access_key,
+                compression=engine.compression,
+                headers=engine.headers
+            )
+        elif isinstance(engine, ReplacingMergeTreeEngine):
+            return ReplacingMergeTreeConfigDict(
+                ver=engine.ver,
+                is_deleted=engine.is_deleted
+            )
+        elif isinstance(engine, AggregatingMergeTreeEngine):
+            return AggregatingMergeTreeConfigDict()
+        elif isinstance(engine, SummingMergeTreeEngine):
+            return SummingMergeTreeConfigDict()
+        elif isinstance(engine, MergeTreeEngine):
+            return MergeTreeConfigDict()
+        else:
+            # Fallback for any other EngineConfig subclass - use base class
+            return BaseEngineConfigDict(engine=engine.__class__.__name__.replace("Engine", ""))
+    
+    # Handle legacy enum-based engine configuration
+    if isinstance(engine, ClickHouseEngines):
+        engine_name = engine.value
+    else:
+        engine_name = str(engine)
+    
+    # For S3Queue with legacy configuration, check for s3_queue_engine_config
+    if engine_name == "S3Queue" and hasattr(table.config, 's3_queue_engine_config'):
+        s3_config = table.config.s3_queue_engine_config
+        if s3_config:
+            logger = Logger(action="S3QueueConfig")
+            logger.highlight(
+                "Using deprecated s3_queue_engine_config. Please migrate to:\n"
+                "  engine=S3QueueEngine(s3_path='...', format='...', ...)"
+            )
+            return S3QueueConfigDict(
+                s3_path=s3_config.path,
+                format=s3_config.format,
+                aws_access_key_id=s3_config.aws_access_key_id,
+                aws_secret_access_key=s3_config.aws_secret_access_key,
+                compression=s3_config.compression,
+                headers=s3_config.headers
+            )
+    
+    # Map engine names to specific config classes
+    engine_map = {
+        "MergeTree": MergeTreeConfigDict,
+        "ReplacingMergeTree": ReplacingMergeTreeConfigDict,
+        "AggregatingMergeTree": AggregatingMergeTreeConfigDict,
+        "SummingMergeTree": SummingMergeTreeConfigDict,
+    }
+    
+    config_class = engine_map.get(engine_name)
+    if config_class:
+        return config_class()
+    
+    # Fallback for unknown engines
+    return BaseEngineConfigDict(engine=engine_name)
+
 def to_infra_map() -> dict:
     """Converts the registered `dmv2` resources into the serializable `InfrastructureMap` format.
 
@@ -268,15 +396,29 @@ def to_infra_map() -> dict:
     workflows = {}
 
     for name, table in get_tables().items():
-        engine = table.config.engine
+        # Convert engine configuration to new format
+        engine_config = None
+        if table.config.engine:
+            engine_config = _convert_engine_to_config_dict(table.config.engine, table)
+        
+        # Get table settings, applying defaults for S3Queue
+        table_settings = table.config.settings.copy() if table.config.settings else {}
+        
+        # Apply default settings for S3Queue if not already specified
+        if engine_config and engine_config.engine == "S3Queue":
+            # Set default mode to 'unordered' if not specified
+            if "mode" not in table_settings:
+                table_settings["mode"] = "unordered"
+        
         tables[name] = TableConfig(
             name=name,
             columns=_to_columns(table._t),
             order_by=table.config.order_by_fields,
-            engine=None if engine is None else engine.value,
+            engine_config=engine_config,
             version=table.config.version,
             metadata=getattr(table, "metadata", None),
             life_cycle=table.config.life_cycle.value if table.config.life_cycle else None,
+            table_settings=table_settings if table_settings else None,  # Map 'settings' to 'table_settings' for internal use
         )
 
     for name, stream in get_streams().items():
@@ -321,10 +463,10 @@ def to_infra_map() -> dict:
                 name=api.config.destination.name
             ),
             metadata=getattr(api, "metadata", None),
-            dead_letter_queue=api.config.dead_letter_queue.name,
             json_schema=api._t.model_json_schema(
                 ref_template='#/components/schemas/{model}'
             ),
+            dead_letter_queue=api.config.dead_letter_queue.name if api.config.dead_letter_queue else None
         )
 
     for name, api in get_apis().items():
